@@ -22,7 +22,7 @@ use Carp;
 use Excel::Writer::XLSX::Chart;
 
 our @ISA     = qw(Excel::Writer::XLSX::Chart);
-our $VERSION = '0.34';
+our $VERSION = '0.35';
 
 
 ###############################################################################
@@ -35,6 +35,7 @@ sub new {
     my $class = shift;
     my $self  = Excel::Writer::XLSX::Chart->new( @_ );
 
+    $self->{_subtype} = $self->{_subtype} // 'marker_only';
     $self->{_cross_between} = 'midCat';
     $self->{_horiz_val_axis}    = 0;
 
@@ -66,7 +67,16 @@ sub _write_chart_type {
 #
 sub _write_scatter_chart {
 
-    my $self = shift;
+    my $self    = shift;
+    my $style   = 'lineMarker';
+    my $subtype = $self->{_subtype};
+
+    # Set the user defined chart subtype.
+    $style = 'lineMarker'   if $subtype eq 'marker_only';
+    $style = 'lineMarker'   if $subtype eq 'straight_with_markers';
+    $style = 'lineMarker'   if $subtype eq 'straight';
+    $style = 'smoothMarker' if $subtype eq 'smooth_with_markers';
+    $style = 'smoothMarker' if $subtype eq 'smooth';
 
     # Add default formatting to the series data.
     $self->_modify_series_formatting();
@@ -74,7 +84,7 @@ sub _write_scatter_chart {
     $self->{_writer}->startTag( 'c:scatterChart' );
 
     # Write the c:scatterStyle element.
-    $self->_write_scatter_style();
+    $self->_write_scatter_style( $style );
 
     # Write the series elements.
     $self->_write_series();
@@ -126,6 +136,9 @@ sub _write_ser {
     # Write the c:yVal element.
     $self->_write_y_val( $series );
 
+    # Write the c:smooth element.
+    $self->_write_c_smooth();
+
     $self->{_writer}->endTag( 'c:ser' );
 }
 
@@ -241,7 +254,7 @@ sub _write_y_val {
 sub _write_scatter_style {
 
     my $self = shift;
-    my $val  = 'lineMarker';
+    my $val  = shift;
 
     my @attributes = ( 'val' => $val );
 
@@ -249,27 +262,71 @@ sub _write_scatter_style {
 }
 
 
+##############################################################################
+#
+# _write_c_smooth()
+#
+# Write the <c:smooth> element.
+#
+sub _write_c_smooth {
+
+    my $self    = shift;
+    my $subtype = $self->{_subtype};
+    my $val     = 1;
+
+    return unless $subtype =~ /smooth/;
+
+    my @attributes = ( 'val' => $val );
+
+    $self->{_writer}->emptyTag( 'c:smooth', @attributes );
+}
+
+
 ##############################################################################
 #
 # _modify_series_formatting()
 #
-# Add default formatting to the series data.
+# Add default formatting to the series data unless it has already been
+# specified by the user.
 #
 sub _modify_series_formatting {
 
-    my $self = shift;
+    my $self    = shift;
+    my $subtype = $self->{_subtype};
 
-    my $index = 0;
-    for my $series ( @{ $self->{_series} } ) {
-        if ( !$series->{_line}->{_defined} ) {
-            $series->{_line} = {
-                width    => 2.25,
-                none     => 1,
-                _defined => 1,
-            };
+    # The default scatter style "markers only" requires a line type.
+    if ( $subtype eq 'marker_only' ) {
+
+        # Go through each series and define default values.
+        for my $series ( @{ $self->{_series} } ) {
+
+            # Set a line type unless there is already a user defined type.
+            if ( !$series->{_line}->{_defined} ) {
+                $series->{_line} = {
+                    width    => 2.25,
+                    none     => 1,
+                    _defined => 1,
+                };
+            }
         }
-        $index++;
     }
+
+    # Turn markers off for subtypes that don't have them.
+    if ( $subtype !~ /marker/ ) {
+
+        # Go through each series and define default values.
+        for my $series ( @{ $self->{_series} } ) {
+
+            # Set a marker type unless there is already a user defined type.
+            if ( !$series->{_marker}->{_defined} ) {
+                $series->{_marker} = {
+                    type     => 'none',
+                    _defined => 1,
+                };
+            }
+        }
+    }
+
 }
 
 
@@ -331,7 +388,20 @@ These methods are explained in detail in L<Excel::Writer::XLSX::Chart>. Class sp
 
 =head1 Scatter Chart Methods
 
-There aren't currently any scatter chart specific methods. See the TODO section of L<Excel::Writer::XLSX::Chart>.
+The C<Scatter> chart module also supports the following sub-types:
+
+    markers_only (the default)
+    straight_with_markers
+    straight
+    smooth_with_markers
+    smooth
+
+These can be specified at creation time via the C<add_chart()> Worksheet method:
+
+    my $chart = $workbook->add_chart(
+        type    => 'scatter',
+        subtype => 'straight_with_markers'
+    );
 
 =head1 EXAMPLE
 
